# eric7.Plugins.VcsPlugins.vcsSubversion.SvnUtilities

Module implementing some common utility functions for the subversion package.

### Global Attributes

None

### Classes

None

### Functions

amendConfig | Module function to amend the config file.
createDefaultConfig | Module function to create a default config file suitable for eric.
getConfigPath | Module function to get the filename of the config file.
getServersPath | Module function to get the filename of the servers file.

## amendConfig

amendConfig()

Module function to amend the config file.

Up

## createDefaultConfig

createDefaultConfig()

Module function to create a default config file suitable for eric.

Up

## getConfigPath

getConfigPath()

Module function to get the filename of the config file.

Return:
  filename of the config file

Return Type:
  str

Up

## getServersPath

getServersPath()

Module function to get the filename of the servers file.

Return:
  filename of the servers file

Return Type:
  str

Up